﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using NUnit.Framework;

using SingularSys.Jep.Functions;
using SingularSys.Jep.Parser;
using SingularSys.Jep.Standard;
using SingularSys.Jep.Types;

namespace SingularSys.Jep.JepTests
{
    [TestFixture]
    public class PrintVisitorTest
    {
        [Test]
        public void testSimpleExpr()
        {
            String simpleExpression = "a+b+c";
            JepInstance jep = new JepInstance();
            jep.Parse(simpleExpression);
            Assert.AreEqual(simpleExpression, jep.RootNodeToString());

            // test full_bracket mode
            simpleExpression = "x*y/z";
            String bracketed = "((x)*(y))/(z)";
            jep.PrintVisitor.SetMode(PrintVisitor.FULL_BRACKET, true);
            jep.Parse(simpleExpression);
            Assert.AreEqual(bracketed, jep.RootNodeToString());
        }

        [Test]
        public void testChildPrintVisitor()
        {
            String expression = "a+b-c";
            JepInstance jep = new JepInstance();
            IJepComponent[] componentArray = { new ValuePrintVisitor() };
            jep.SetComponents(componentArray);
        }

        class ValuePrintVisitor : PrintVisitor
        {
            public override object Visit(ASTConstant node, object data)
            {
                sb.Append(node.Value);
                return data;
            }
        }
    }
}
